@@ -2,37 +2,30 @@ from shrub.v3.evg_command import EvgCommandType
 from shrub.v3.evg_command import s3_put
 from shrub.v3.evg_task import EvgTask
 
+from config_generator.components.funcs.set_cache_dir import SetCacheDir
+
 from config_generator.etc.function import Function
 from config_generator.etc.utils import bash_exec
 
 
 class CheckABICompliance(Function):
     name = 'abi-compliance-check'
-    commands = [
+    commands = SetCacheDir.commands + [
         bash_exec(
             command_type=EvgCommandType.SETUP,
             working_dir='mongoc',
+            include_expansions_in_env=['MONGO_C_DRIVER_CACHE_DIR'],
             script='.evergreen/scripts/abi-compliance-check-setup.sh'
         ),
         bash_exec(
-            command_type=EvgCommandType.SETUP,
+            command_type=EvgCommandType.TEST,
             add_expansions_to_env=True,
             working_dir='mongoc',
+            include_expansions_in_env=['MONGO_C_DRIVER_CACHE_DIR'],
             script='.evergreen/scripts/abi-compliance-check.sh'
         ),
-        bash_exec(
-            command_type=EvgCommandType.TEST,
-            working_dir='mongoc',
-            env={
-                'AWS_ACCESS_KEY_ID': '${aws_key}',
-                'AWS_SECRET_ACCESS_KEY': '${aws_secret}',
-            },
-            script='''\
-                aws s3 cp abi-compliance/compat_reports s3://mciuploads/${project}/${build_variant}/${revision}/${version_id}/${build_id}/abi-compliance/compat_reports --recursive --acl public-read --region us-east-1
-                [[ ! -f ./abi-compliance/abi-error.txt ]]
-            '''
-        ),
         s3_put(
+            command_type=EvgCommandType.SYSTEM,
             aws_key='${aws_key}',
             aws_secret='${aws_secret}',
             bucket='mciuploads',
@@ -40,7 +33,18 @@ class CheckABICompliance(Function):
             display_name='ABI Report:',
             local_files_include_filter='mongoc/abi-compliance/compat_reports/**/*.html',
             permissions='public-read',
-            remote_file='${project}/${build_variant}/${revision}/${version_id}/${build_id}/abi-compliance/compat_report.html',
+            remote_file='mongo-c-driver/${branch_name}/${revision}/${version_id}/${build_id}/${task_id}/${execution}/abi-compliance-check/',
+        ),
+        s3_put(
+            command_type=EvgCommandType.SYSTEM,
+            aws_key='${aws_key}',
+            aws_secret='${aws_secret}',
+            bucket='mciuploads',
+            content_type='text/plain',
+            display_name='ABI Compliance Check: ',
+            local_files_include_filter='abi-compliance/logs/**/log.txt',
+            permissions='public-read',
+            remote_file='mongo-c-driver/${branch_name}/${revision}/${version_id}/${build_id}/${task_id}/${execution}/abi-compliance-check/',
         ),
     ]
 
