@@ -17,7 +17,7 @@ class FetchBuild(Function):
             aws_secret='${aws_secret}',
             bucket='mciuploads',
             local_file='build.tar.gz',
-            remote_file='${project}/${build_variant}/${revision}/${BUILD_NAME}/${build_id}.tar.gz',
+            remote_file='mongo-c-driver/${build_variant}/${revision}/${BUILD_NAME}/${build_id}.tar.gz',
         ),
         archive_targz_extract(path='build.tar.gz', destination='mongoc'),
         # Scripts may not be executable on Windows.
@@ -33,8 +33,11 @@ class FetchBuild(Function):
     ]
 
     @classmethod
-    def call(cls, build_name, **kwargs):
-        return cls.default_call(vars={'BUILD_NAME': build_name}, **kwargs)
+    def call(cls, build_name, vars=None, **kwargs):
+        if vars is None:
+            vars = {}
+        vars.update({'BUILD_NAME': build_name})
+        return cls.default_call(vars=vars, **kwargs)
 
 
 def functions():
