@@ -649,7 +649,6 @@ class AuthTask(MatrixTask):
 
     def post_commands(self) -> Iterable[Value]:
         yield func("fetch-build", BUILD_NAME=self.build_task_name)
-        yield func("prepare-kerberos")
         yield func("run auth tests")
 
     @property
@@ -701,7 +700,6 @@ all_tasks = chain(
             """,
                     add_expansions_to_env=True,
                 ),
-                func("prepare-kerberos"),
                 func("run auth tests", ASAN="on"),
             ],
         )
