@@ -109,10 +109,9 @@ if [[ "${OSTYPE}" == darwin* ]]; then
   }
 fi
 
-# Allow reuse of ccache compilation results between different build directories.
-export CCACHE_BASEDIR CCACHE_NOHASHDIR
-CCACHE_BASEDIR="$(pwd)"
-CCACHE_NOHASHDIR=1
+# Use ccache if able.
+. "${script_dir:?}/find-ccache.sh"
+find_ccache_and_export_vars "$(pwd)" || true
 
 "${CMAKE}" "${configure_flags[@]}" .
 "${CMAKE}" --build . -- -j "$(nproc)"
