@@ -1,5 +1,5 @@
 /*
- * Copyright 2015 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,13 +15,13 @@
  */
 
 
-#include "bson-prelude.h"
+#include <bson/bson-prelude.h>
 
 
 #ifndef BSON_VERSION_FUNCTIONS_H
 #define BSON_VERSION_FUNCTIONS_H
 
-#include "bson-types.h"
+#include <bson/bson-types.h>
 
 BSON_BEGIN_DECLS
 
