@@ -8,7 +8,7 @@ domain plugin. If that is the case, this extention can likely be disabled and
 replaced by a more full-featured extension.
 
 """
-from typing import Any
+from typing import Any, List
 from sphinx.application import Sphinx
 from sphinx.roles import XRefRole
 from sphinx.domains import Domain, ObjType
@@ -38,11 +38,12 @@ class CMakeRefDomain(Domain):
     name = "cmake"
     label = "CMake (Minimal)"
     object_types = {k: ObjType(k, k) for k in kinds}
-    roles = {k: XRefRole() for k in kinds} | {"command": XRefRole(fix_parens=True)}
+    roles = {k: XRefRole() for k in kinds}
+    roles["command"] = XRefRole(fix_parens=True)
     directives = {}
     initial_data: Any = {}
 
-    def merge_domaindata(self, docnames: list[str], otherdata: Any) -> None:
+    def merge_domaindata(self, docnames: List[str], otherdata: Any) -> None:
         # We have nothing to do, but this is required for parallel execution
         return
 
