@@ -47,7 +47,7 @@ bulk4 (mongoc_collection_t *collection)
 }
 
 int
-main (int argc, char *argv[])
+main (void)
 {
    mongoc_client_t *client;
    mongoc_collection_t *collection;
