@@ -1,5 +1,5 @@
 /*
- * Copyright 2013 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,22 +15,27 @@
  */
 
 
-#include "mongoc.h"
-#include "mongoc-apm-private.h"
-#include "mongoc-array-private.h"
-#include "mongoc-counters-private.h"
-#include "mongoc-client-pool-private.h"
-#include "mongoc-client-pool.h"
-#include "mongoc-client-private.h"
-#include "mongoc-client-side-encryption-private.h"
-#include "mongoc-queue-private.h"
-#include "mongoc-thread-private.h"
-#include "mongoc-topology-private.h"
-#include "mongoc-topology-background-monitoring-private.h"
-#include "mongoc-trace-private.h"
+#include <mongoc/mongoc.h>
+#include <mongoc/mongoc-apm-private.h>
+#include <mongoc/mongoc-array-private.h>
+#include <mongoc/mongoc-counters-private.h>
+#include <mongoc/mongoc-client-pool-private.h>
+#include <mongoc/mongoc-client-pool.h>
+#include <mongoc/mongoc-client-private.h>
+#include <mongoc/mongoc-client-side-encryption-private.h>
+#include <mongoc/mongoc-log-and-monitor-private.h>
+#include <mongoc/mongoc-queue-private.h>
+#include <mongoc/mongoc-thread-private.h>
+#include <mongoc/mongoc-topology-private.h>
+#include <mongoc/mongoc-topology-background-monitoring-private.h>
+#include <mongoc/mongoc-trace-private.h>
 
 #ifdef MONGOC_ENABLE_SSL
-#include "mongoc-ssl-private.h"
+#include <mongoc/mongoc-ssl-private.h>
+#endif
+
+#if defined(MONGOC_ENABLE_SSL_OPENSSL) && OPENSSL_VERSION_NUMBER >= 0x10100000L
+#include <mongoc/mongoc-openssl-private.h>
 #endif
 
 struct _mongoc_client_pool_t {
@@ -43,16 +48,15 @@ struct _mongoc_client_pool_t {
    uint32_t max_pool_size;
    uint32_t size;
 #ifdef MONGOC_ENABLE_SSL
-   bool ssl_opts_set;
    mongoc_ssl_opt_t ssl_opts;
+   bool ssl_opts_set;
 #endif
    bool apm_callbacks_set;
-   mongoc_apm_callbacks_t apm_callbacks;
-   void *apm_context;
-   int32_t error_api_version;
    bool error_api_set;
-   mongoc_server_api_t *api;
+   bool structured_log_opts_set;
    bool client_initialized;
+   int32_t error_api_version;
+   mongoc_server_api_t *api;
    // `last_known_serverids` is a sorted array of uint32_t.
    mongoc_array_t last_known_serverids;
 };
@@ -73,6 +77,13 @@ mongoc_client_pool_set_ssl_opts (mongoc_client_pool_t *pool, const mongoc_ssl_op
    if (opts) {
       _mongoc_ssl_opts_copy_to (opts, &pool->ssl_opts, false /* don't overwrite internal opts. */);
       pool->ssl_opts_set = true;
+
+      /* Update the OpenSSL context associated with this client pool to match new ssl opts. */
+      /* All future clients popped from pool inherit this OpenSSL context. */
+#if defined(MONGOC_ENABLE_SSL_OPENSSL) && OPENSSL_VERSION_NUMBER >= 0x10100000L
+      SSL_CTX_free (pool->topology->scanner->openssl_ctx);
+      pool->topology->scanner->openssl_ctx = _mongoc_openssl_ctx_new (&pool->ssl_opts);
+#endif
    }
 
    mongoc_topology_scanner_set_ssl_opts (pool->topology->scanner, &pool->ssl_opts);
@@ -270,9 +281,7 @@ _initialize_new_client (mongoc_client_pool_t *pool, mongoc_client_t *client)
       client, pool->topology->scanner->initiator, pool->topology->scanner->initiator_context);
 
    pool->client_initialized = true;
-   client->is_pooled = true;
    client->error_api_version = pool->error_api_version;
-   _mongoc_client_set_apm_callbacks_private (client, &pool->apm_callbacks, pool->apm_context);
 
    client->api = mongoc_server_api_copy (pool->api);
 
@@ -566,35 +575,51 @@ bool
 mongoc_client_pool_set_apm_callbacks (mongoc_client_pool_t *pool, mongoc_apm_callbacks_t *callbacks, void *context)
 {
    BSON_ASSERT_PARAM (pool);
+   BSON_OPTIONAL_PARAM (callbacks);
+   BSON_OPTIONAL_PARAM (context);
 
-   mongoc_topology_t *const topology = BSON_ASSERT_PTR_INLINE (pool)->topology;
-   mc_tpld_modification tdmod = mc_tpld_modify_begin (topology);
-
-   // Prevent setting callbacks more than once
+   // Enforce documented thread-safety restrictions
    if (pool->apm_callbacks_set) {
-      mc_tpld_modify_drop (tdmod);
-      MONGOC_ERROR ("Can only set callbacks once");
+      MONGOC_ERROR ("mongoc_client_pool_set_apm_callbacks can only be called once per pool");
       return false;
-   }
+   } else if (pool->client_initialized) {
+      MONGOC_ERROR ("mongoc_client_pool_set_apm_callbacks can only be called before mongoc_client_pool_pop");
+      /* @todo Since 2017 this requirement has been documented but not actually enforced. For now we are leaving it
+       * unenforced, for backward compatibility. This usage remains unsafe and incorrect. When possible, this should be
+       * modified to return false without modifying the APM callbacks. */
+      mongoc_log_and_monitor_instance_set_apm_callbacks (&pool->topology->log_and_monitor, callbacks, context);
+      pool->apm_callbacks_set = true;
+      return true;
 
-   // Update callbacks on the pool
-   if (callbacks) {
-      pool->apm_callbacks = *callbacks;
    } else {
-      pool->apm_callbacks = (mongoc_apm_callbacks_t){0};
+      // Now we can be sure no other threads are relying on concurrent access to the instance yet.
+      mongoc_log_and_monitor_instance_set_apm_callbacks (&pool->topology->log_and_monitor, callbacks, context);
+      pool->apm_callbacks_set = true;
+      return true;
    }
-   pool->apm_context = context;
+}
 
-   // Update callbacks on the topology
-   mongoc_topology_set_apm_callbacks (topology, tdmod.new_td, callbacks, context);
+bool
+mongoc_client_pool_set_structured_log_opts (mongoc_client_pool_t *pool, const mongoc_structured_log_opts_t *opts)
+{
+   BSON_ASSERT_PARAM (pool);
+   BSON_OPTIONAL_PARAM (opts);
 
-   // Signal that we have already set the callbacks
-   pool->apm_callbacks_set = true;
-
-   // Save our updated topology
-   mc_tpld_modify_commit (tdmod);
-
-   return true;
+   /* The documented restriction for most pool options: They can be set at most once,
+    * and only before the first client is initialized. Structured logging is generally
+    * expected to warn but not quit when encountering initialization errors. */
+   if (pool->structured_log_opts_set) {
+      MONGOC_ERROR ("mongoc_client_pool_set_structured_log_opts can only be called once per pool");
+      return false;
+   } else if (pool->client_initialized) {
+      MONGOC_ERROR ("mongoc_client_pool_set_structured_log_opts can only be called before mongoc_client_pool_pop");
+      return false;
+   } else {
+      // Now we can be sure no other threads are relying on concurrent access to the instance yet.
+      mongoc_log_and_monitor_instance_set_structured_log_opts (&pool->topology->log_and_monitor, opts);
+      pool->structured_log_opts_set = true;
+      return true;
+   }
 }
 
 bool
