@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-#include "mongoc-prelude.h"
+#include <mongoc/mongoc-prelude.h>
 
 #ifndef MONGOC_CLIENT_SIDE_ENCRYPTION_H
 #define MONGOC_CLIENT_SIDE_ENCRYPTION_H
@@ -71,6 +71,9 @@ mongoc_auto_encryption_opts_set_keyvault_namespace (mongoc_auto_encryption_opts_
 MONGOC_EXPORT (void)
 mongoc_auto_encryption_opts_set_kms_providers (mongoc_auto_encryption_opts_t *opts, const bson_t *kms_providers);
 
+MONGOC_EXPORT (void)
+mongoc_auto_encryption_opts_set_key_expiration (mongoc_auto_encryption_opts_t *opts, uint64_t expiration);
+
 MONGOC_EXPORT (void)
 mongoc_auto_encryption_opts_set_tls_opts (mongoc_auto_encryption_opts_t *opts, const bson_t *tls_opts);
 
@@ -130,6 +133,9 @@ mongoc_client_encryption_opts_set_kms_credential_provider_callback (mongoc_clien
                                                                     mongoc_kms_credentials_provider_callback_fn fn,
                                                                     void *userdata);
 
+MONGOC_EXPORT (void)
+mongoc_client_encryption_opts_set_key_expiration (mongoc_client_encryption_opts_t *opts, uint64_t cache_expiration_ms);
+
 MONGOC_EXPORT (mongoc_client_encryption_rewrap_many_datakey_result_t *)
 mongoc_client_encryption_rewrap_many_datakey_result_new (void) BSON_GNUC_WARN_UNUSED_RESULT;
 
