@@ -1,5 +1,5 @@
 /*
- * Copyright 2017 MongoDB Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,11 +15,12 @@
  */
 
 
-#include "mongoc/mongoc-config.h"
+#include <mongoc/mongoc-config.h>
 
-#include "mongoc/mongoc-compression-private.h"
-#include "mongoc/mongoc-trace-private.h"
-#include "mongoc/mongoc-util-private.h"
+#include <mongoc/mongoc-compression-private.h>
+#include <mongoc/mongoc-trace-private.h>
+#include <mongoc/mongoc-util-private.h>
+#include <common-cmp-private.h>
 
 #ifdef MONGOC_ENABLE_COMPRESSION
 #ifdef MONGOC_ENABLE_COMPRESSION_ZLIB
@@ -36,30 +37,25 @@
 size_t
 mongoc_compressor_max_compressed_length (int32_t compressor_id, size_t len)
 {
-   TRACE ("Getting compression length for '%s' (%d)",
-          mongoc_compressor_id_to_name (compressor_id),
-          compressor_id);
+   TRACE ("Getting compression length for '%s' (%d)", mongoc_compressor_id_to_name (compressor_id), compressor_id);
    switch (compressor_id) {
 #ifdef MONGOC_ENABLE_COMPRESSION_SNAPPY
    case MONGOC_COMPRESSOR_SNAPPY_ID:
       return snappy_max_compressed_length (len);
-      break;
 #endif
 
 #ifdef MONGOC_ENABLE_COMPRESSION_ZLIB
    case MONGOC_COMPRESSOR_ZLIB_ID:
-      return compressBound (len);
-      break;
+      BSON_ASSERT (mcommon_in_range_unsigned (unsigned_long, len));
+      return compressBound ((unsigned long) len);
 #endif
 
 #ifdef MONGOC_ENABLE_COMPRESSION_ZSTD
    case MONGOC_COMPRESSOR_ZSTD_ID:
       return ZSTD_compressBound (len);
-      break;
 #endif
    case MONGOC_COMPRESSOR_NOOP_ID:
       return len;
-      break;
    default:
       return 0;
    }
@@ -142,6 +138,9 @@ mongoc_compressor_name_to_id (const char *compressor)
    return -1;
 }
 
+// To support unchecked casts from `unsigned long` to `size_t`.
+BSON_STATIC_ASSERT2 (size_t_gte_ulong, SIZE_MAX >= ULONG_MAX);
+
 bool
 mongoc_uncompress (int32_t compressor_id,
                    const uint8_t *compressed,
@@ -149,18 +148,17 @@ mongoc_uncompress (int32_t compressor_id,
                    uint8_t *uncompressed,
                    size_t *uncompressed_len)
 {
-   TRACE ("Uncompressing with '%s' (%d)",
-          mongoc_compressor_id_to_name (compressor_id),
-          compressor_id);
+   BSON_ASSERT_PARAM (compressed);
+   BSON_ASSERT_PARAM (uncompressed);
+   BSON_ASSERT_PARAM (uncompressed_len);
+
+   TRACE ("Uncompressing with '%s' (%d)", mongoc_compressor_id_to_name (compressor_id), compressor_id);
 
    switch (compressor_id) {
    case MONGOC_COMPRESSOR_SNAPPY_ID: {
 #ifdef MONGOC_ENABLE_COMPRESSION_SNAPPY
-      snappy_status status;
-      status = snappy_uncompress ((const char *) compressed,
-                                  compressed_len,
-                                  (char *) uncompressed,
-                                  uncompressed_len);
+      const snappy_status status =
+         snappy_uncompress ((const char *) compressed, compressed_len, (char *) uncompressed, uncompressed_len);
 
       return status == SNAPPY_OK;
 #else
@@ -168,50 +166,61 @@ mongoc_uncompress (int32_t compressor_id,
                       "compression is not compiled in");
       return false;
 #endif
-      break;
    }
 
    case MONGOC_COMPRESSOR_ZLIB_ID: {
 #ifdef MONGOC_ENABLE_COMPRESSION_ZLIB
-      int ok;
+      // Malformed message: unrepresentable.
+      if (BSON_UNLIKELY (!mcommon_in_range_unsigned (unsigned_long, compressed_len))) {
+         return false;
+      }
 
-      ok = uncompress (uncompressed,
-                       (unsigned long *) uncompressed_len,
-                       compressed,
-                       compressed_len);
+      // Malformed message: unrepresentable.
+      if (BSON_UNLIKELY (!mcommon_in_range_unsigned (unsigned_long, *uncompressed_len))) {
+         return false;
+      }
 
-      return ok == Z_OK;
+      uLong actual_uncompressed_len = (uLong) *uncompressed_len;
+
+      const int res =
+         uncompress (uncompressed, &actual_uncompressed_len, (const Bytef *) compressed, (uLong) compressed_len);
+
+      if (BSON_UNLIKELY (res != Z_OK)) {
+         return false;
+      }
+
+      *uncompressed_len = (size_t) actual_uncompressed_len;
+
+      return true;
 #else
       MONGOC_WARNING ("Received zlib compressed opcode, but zlib "
                       "compression is not compiled in");
       return false;
 #endif
-      break;
    }
 
    case MONGOC_COMPRESSOR_ZSTD_ID: {
 #ifdef MONGOC_ENABLE_COMPRESSION_ZSTD
-      int ok;
+      const size_t res = ZSTD_decompress (uncompressed, *uncompressed_len, compressed, compressed_len);
 
-      ok =
-         ZSTD_decompress ((void *) uncompressed,
-                          *uncompressed_len,
-                          (const void *) compressed,
-                          compressed_len);
-
-      if (!ZSTD_isError (ok)) {
-         *uncompressed_len = ok;
+      if (BSON_UNLIKELY (ZSTD_isError (res))) {
+         return false;
       }
 
-      return !ZSTD_isError (ok);
+      *uncompressed_len = res;
+
+      return true;
 #else
       MONGOC_WARNING ("Received zstd compressed opcode, but zstd "
                       "compression is not compiled in");
       return false;
 #endif
-      break;
    }
    case MONGOC_COMPRESSOR_NOOP_ID:
+      // Malformed message: not enough space.
+      if (BSON_UNLIKELY (*uncompressed_len < compressed_len)) {
+         return false;
+      }
       memcpy (uncompressed, compressed, compressed_len);
       *uncompressed_len = compressed_len;
       return true;
@@ -231,16 +240,12 @@ mongoc_compress (int32_t compressor_id,
                  char *compressed,
                  size_t *compressed_len)
 {
-   TRACE ("Compressing with '%s' (%d)",
-          mongoc_compressor_id_to_name (compressor_id),
-          compressor_id);
+   TRACE ("Compressing with '%s' (%d)", mongoc_compressor_id_to_name (compressor_id), compressor_id);
    switch (compressor_id) {
    case MONGOC_COMPRESSOR_SNAPPY_ID:
 #ifdef MONGOC_ENABLE_COMPRESSION_SNAPPY
       /* No compression_level option for snappy */
-      return snappy_compress (
-                uncompressed, uncompressed_len, compressed, compressed_len) ==
-             SNAPPY_OK;
+      return snappy_compress (uncompressed, uncompressed_len, compressed, compressed_len) == SNAPPY_OK;
 #else
       MONGOC_ERROR ("Client attempting to use compress with snappy, but snappy "
                     "compression is not compiled in");
@@ -249,10 +254,11 @@ mongoc_compress (int32_t compressor_id,
 
    case MONGOC_COMPRESSOR_ZLIB_ID:
 #ifdef MONGOC_ENABLE_COMPRESSION_ZLIB
+      BSON_ASSERT (mcommon_in_range_unsigned (unsigned_long, uncompressed_len));
       return compress2 ((unsigned char *) compressed,
                         (unsigned long *) compressed_len,
                         (unsigned char *) uncompressed,
-                        uncompressed_len,
+                        (unsigned long) uncompressed_len,
                         compression_level) == Z_OK;
 #else
       MONGOC_ERROR ("Client attempting to use compress with zlib, but zlib "
@@ -264,11 +270,7 @@ mongoc_compress (int32_t compressor_id,
 #ifdef MONGOC_ENABLE_COMPRESSION_ZSTD
       int ok;
 
-      ok = ZSTD_compress ((void *) compressed,
-                          *compressed_len,
-                          (const void *) uncompressed,
-                          uncompressed_len,
-                          compression_level);
+      ok = ZSTD_compress ((void *) compressed, *compressed_len, (const void *) uncompressed, uncompressed_len, 0);
 
       if (!ZSTD_isError (ok)) {
          *compressed_len = ok;
