@@ -1,5 +1,5 @@
 /*
- * Copyright 2013 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,12 +14,15 @@
  * limitations under the License.
  */
 
-#include "mongoc-prelude.h"
+#include <mongoc/mongoc-prelude.h>
+
+#ifndef MONGOC_ERROR_PRIVATE_H
+#define MONGOC_ERROR_PRIVATE_H
 
 #include <bson/bson.h>
 #include <stddef.h>
 
-#include "mongoc-server-description.h"
+#include <mongoc/mongoc-server-description.h>
 
 BSON_BEGIN_DECLS
 
@@ -89,4 +92,19 @@ _mongoc_error_is_server (const bson_error_t *error);
 bool
 _mongoc_error_is_auth (const bson_error_t *error);
 
+/* Try to append `s` to `error`. Truncates `s` if `error` is out of space. */
+void
+_mongoc_error_append (bson_error_t *error, const char *s);
+
+typedef enum {
+   MONGOC_ERROR_CONTENT_FLAG_CODE = (1 << 0),
+   MONGOC_ERROR_CONTENT_FLAG_DOMAIN = (1 << 1),
+   MONGOC_ERROR_CONTENT_FLAG_MESSAGE = (1 << 2),
+} mongoc_error_content_flags_t;
+
+bool
+mongoc_error_append_contents_to_bson (const bson_error_t *error, bson_t *bson, mongoc_error_content_flags_t flags);
+
 BSON_END_DECLS
+
+#endif /* MONGOC_ERROR_PRIVATE_H */
