@@ -1,5 +1,5 @@
 /*
- * Copyright 2016 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,13 +14,13 @@
  * limitations under the License.
  */
 
-#include "mongoc-prelude.h"
+#include <mongoc/mongoc-prelude.h>
 
 
 #ifndef MONGOC_HANDSHAKE_PRIVATE_H
 #define MONGOC_HANDSHAKE_PRIVATE_H
 
-#include "mongoc.h"
+#include <mongoc/mongoc.h>
 
 BSON_BEGIN_DECLS
 
@@ -83,6 +83,7 @@ typedef enum {
    MONGOC_MD_FLAG_ENABLE_CLIENT_SIDE_ENCRYPTION = 32,
    MONGOC_MD_FLAG_ENABLE_MONGODB_AWS_AUTH = 33,
    MONGOC_MD_FLAG_ENABLE_SRV = 34,
+   MONGOC_MD_FLAG_HAVE_BCRYPT_PBKDF2 = 35,
    /* Add additional config flags here, above LAST_MONGOC_MD_FLAG. */
    LAST_MONGOC_MD_FLAG
 } mongoc_handshake_config_flag_bit_t;
