@@ -1,5 +1,5 @@
 /*
- * Copyright 2015 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,9 +15,9 @@
  */
 
 
-#include "mongoc-cluster-private.h"
-#include "mongoc-server-stream-private.h"
-#include "mongoc-util-private.h"
+#include <mongoc/mongoc-cluster-private.h>
+#include <mongoc/mongoc-server-stream-private.h>
+#include <mongoc/mongoc-util-private.h>
 
 #undef MONGOC_LOG_DOMAIN
 #define MONGOC_LOG_DOMAIN "server-stream"
