@@ -1,5 +1,5 @@
 /*
- * Copyright 2013 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,23 +14,22 @@
  * limitations under the License.
  */
 
-#include "mongoc-prelude.h"
+#include <mongoc/mongoc-prelude.h>
 
 #ifndef MONGOC_STREAM_BUFFERED_H
 #define MONGOC_STREAM_BUFFERED_H
 
 #include <bson/bson.h>
 
-#include "mongoc-macros.h"
-#include "mongoc-stream.h"
+#include <mongoc/mongoc-macros.h>
+#include <mongoc/mongoc-stream.h>
 
 
 BSON_BEGIN_DECLS
 
 
 MONGOC_EXPORT (mongoc_stream_t *)
-mongoc_stream_buffered_new (mongoc_stream_t *base_stream,
-                        size_t buffer_size) BSON_GNUC_WARN_UNUSED_RESULT;
+mongoc_stream_buffered_new (mongoc_stream_t *base_stream, size_t buffer_size) BSON_GNUC_WARN_UNUSED_RESULT;
 
 
 BSON_END_DECLS
