@@ -1,5 +1,5 @@
 /*
- * Copyright 2018-present MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,11 +14,11 @@
  * limitations under the License.
  */
 
-#include "mongoc-stream-gridfs-download-private.h"
-#include "mongoc-gridfs-bucket-file-private.h"
-#include "mongoc-counters-private.h"
-#include "mongoc-trace-private.h"
-#include "mongoc-stream-private.h"
+#include <mongoc/mongoc-stream-gridfs-download-private.h>
+#include <mongoc/mongoc-gridfs-bucket-file-private.h>
+#include <mongoc/mongoc-counters-private.h>
+#include <mongoc/mongoc-trace-private.h>
+#include <mongoc/mongoc-stream-private.h>
 
 #undef MONGOC_LOG_DOMAIN
 #define MONGOC_LOG_DOMAIN "stream-gridfs-download"
