@@ -1,5 +1,5 @@
 /*
- * Copyright 2013-present MongoDB Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,16 +14,16 @@
  * limitations under the License.
  */
 
-#include "mongoc-prelude.h"
+#include <mongoc/mongoc-prelude.h>
 
 #ifndef MONGOC_THREAD_PRIVATE_H
 #define MONGOC_THREAD_PRIVATE_H
 
 #include <bson/bson.h>
 
-#include "common-thread-private.h"
-#include "mongoc-config.h"
-#include "mongoc-log.h"
+#include <common-thread-private.h>
+#include <mongoc/mongoc-config.h>
+#include <mongoc/mongoc-log.h>
 
 #if defined(BSON_OS_UNIX)
 #define mongoc_cond_t pthread_cond_t
