@@ -1,6 +1,6 @@
 
 /*
- * Copyright 2020-present MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,13 +15,13 @@
  * limitations under the License.
  */
 
-#include "mongoc-prelude.h"
+#include <mongoc/mongoc-prelude.h>
 
 #ifndef MONGOC_TOPOLOGY_BACKGROUND_MONITORING_PRIVATE_H
 #define MONGOC_TOPOLOGY_BACKGROUND_MONITORING_PRIVATE_H
 
-#include "mongoc.h"
-#include "mongoc-topology-private.h"
+#include <mongoc/mongoc.h>
+#include <mongoc/mongoc-topology-private.h>
 
 /* Methods of mongoc_topology_t for managing background monitoring. */
 
