@@ -15,15 +15,15 @@
  */
 
 #include "bsonutil/bson-match.h"
-#include "mongoc-util-private.h" // hex_to_bin
+#include <mongoc/mongoc-util-private.h> // hex_to_bin
 #include "test-conveniences.h"
 #include "TestSuite.h"
 #include "unified/util.h"
-#include "utlist.h"
+#include <mongoc/utlist.h>
 
 typedef struct _special_functor_t {
    special_fn fn;
-   void *ctx;
+   void *user_data;
    char *keyword;
    struct _special_functor_t *next;
 } special_functor_t;
@@ -32,7 +32,7 @@ struct _bson_matcher_t {
    special_functor_t *specials;
 };
 
-#define MATCH_ERR(format, ...) test_set_error (error, "match error at path: '%s': " format, path, __VA_ARGS__)
+#define MATCH_ERR(format, ...) test_set_error (error, "match error at path: '%s': " format, context->path, __VA_ARGS__)
 
 static char *
 get_first_key (const bson_t *bson)
@@ -62,18 +62,16 @@ is_special_match (const bson_t *bson)
 
 /* implements $$placeholder */
 static bool
-special_placeholder (bson_matcher_t *matcher,
+special_placeholder (const bson_matcher_context_t *context,
                      const bson_t *assertion,
                      const bson_val_t *actual,
-                     void *ctx,
-                     const char *path,
+                     void *user_data,
                      bson_error_t *error)
 {
-   BSON_UNUSED (matcher);
+   BSON_UNUSED (context);
    BSON_UNUSED (assertion);
    BSON_UNUSED (actual);
-   BSON_UNUSED (ctx);
-   BSON_UNUSED (path);
+   BSON_UNUSED (user_data);
    BSON_UNUSED (error);
 
    /* Nothing to do (not an operator, just a reserved key value). The meaning
@@ -83,19 +81,18 @@ special_placeholder (bson_matcher_t *matcher,
 
 /* implements $$exists */
 static bool
-special_exists (bson_matcher_t *matcher,
+special_exists (const bson_matcher_context_t *context,
                 const bson_t *assertion,
                 const bson_val_t *actual,
-                void *ctx,
-                const char *path,
+                void *user_data,
                 bson_error_t *error)
 {
    bool ret = false;
    bson_iter_t iter;
    bool should_exist;
 
-   BSON_UNUSED (matcher);
-   BSON_UNUSED (ctx);
+   BSON_UNUSED (context);
+   BSON_UNUSED (user_data);
 
    bson_iter_init (&iter, assertion);
    BSON_ASSERT (bson_iter_next (&iter));
@@ -122,18 +119,17 @@ done:
 
 /* implements $$type */
 static bool
-special_type (bson_matcher_t *matcher,
+special_type (const bson_matcher_context_t *context,
               const bson_t *assertion,
               const bson_val_t *actual,
-              void *ctx,
-              const char *path,
+              void *user_data,
               bson_error_t *error)
 {
    bool ret = false;
    bson_iter_t iter;
 
-   BSON_UNUSED (matcher);
-   BSON_UNUSED (ctx);
+   BSON_UNUSED (context);
+   BSON_UNUSED (user_data);
 
    bson_iter_init (&iter, assertion);
    BSON_ASSERT (bson_iter_next (&iter));
@@ -187,18 +183,17 @@ done:
 
 /* implements $$unsetOrMatches */
 static bool
-special_unset_or_matches (bson_matcher_t *matcher,
+special_unset_or_matches (const bson_matcher_context_t *context,
                           const bson_t *assertion,
                           const bson_val_t *actual,
-                          void *ctx,
-                          const char *path,
+                          void *user_data,
                           bson_error_t *error)
 {
    bool ret = false;
    bson_iter_t iter;
    bson_val_t *expected = NULL;
 
-   BSON_UNUSED (ctx);
+   BSON_UNUSED (user_data);
 
    bson_iter_init (&iter, assertion);
    BSON_ASSERT (bson_iter_next (&iter));
@@ -209,7 +204,7 @@ special_unset_or_matches (bson_matcher_t *matcher,
       goto done;
    }
 
-   if (!bson_matcher_match (matcher, expected, actual, path, false, error)) {
+   if (!bson_matcher_match (context, expected, actual, error)) {
       goto done;
    }
 
@@ -221,11 +216,10 @@ done:
 
 /* implements $$matchesHexBytes */
 static bool
-special_matches_hex_bytes (bson_matcher_t *matcher,
+special_matches_hex_bytes (const bson_matcher_context_t *context,
                            const bson_t *assertion,
                            const bson_val_t *actual,
-                           void *ctx,
-                           const char *path,
+                           void *user_data,
                            bson_error_t *error)
 {
    bool ret = false;
@@ -237,8 +231,8 @@ special_matches_hex_bytes (bson_matcher_t *matcher,
    char *actual_bytes_string = NULL;
    bson_iter_t iter;
 
-   BSON_UNUSED (matcher);
-   BSON_UNUSED (ctx);
+   BSON_UNUSED (context);
+   BSON_UNUSED (user_data);
 
    bson_iter_init (&iter, assertion);
    BSON_ASSERT (bson_iter_next (&iter));
@@ -288,14 +282,102 @@ special_matches_hex_bytes (bson_matcher_t *matcher,
    bson_free (actual_bytes_string);
 
    ret = true;
-   goto done;
+done:
+   return ret;
+}
+
+/* implements $$matchAsDocument */
+static bool
+special_match_as_document (const bson_matcher_context_t *context,
+                           const bson_t *assertion,
+                           const bson_val_t *actual,
+                           void *user_data,
+                           bson_error_t *error)
+{
+   bool ret = false;
+   bson_t actual_as_bson = BSON_INITIALIZER;
+   BSON_UNUSED (user_data);
+
+   bson_iter_t iter;
+   bson_iter_init (&iter, assertion);
+   BSON_ASSERT (bson_iter_next (&iter));
+   if (!BSON_ITER_HOLDS_DOCUMENT (&iter)) {
+      MATCH_ERR ("%s", "$$matchAsDocument does not contain a document");
+      goto done;
+   }
+
+   if (!actual) {
+      MATCH_ERR ("%s", "does not exist but should");
+      goto done;
+   }
+
+   if (bson_val_type (actual) != BSON_TYPE_UTF8) {
+      MATCH_ERR ("%s", "value type is not utf8");
+      goto done;
+   }
+   const char *actual_json = bson_val_to_utf8 (actual);
+   if (!bson_init_from_json (&actual_as_bson, actual_json, -1, error)) {
+      MATCH_ERR ("%s", "value can't be parsed as JSON");
+      goto done;
+   }
+
+   bson_val_t *expected_val = bson_val_from_iter (&iter);
+   bson_val_t *actual_val = bson_val_from_bson (&actual_as_bson);
+   ret = bson_matcher_match (context, expected_val, actual_val, error);
+   bson_val_destroy (actual_val);
+   bson_val_destroy (expected_val);
+   bson_destroy (&actual_as_bson);
+
+done:
+
+   return ret;
+}
+
+/* implements $$matchAsRoot */
+static bool
+special_match_as_root (const bson_matcher_context_t *context,
+                       const bson_t *assertion,
+                       const bson_val_t *actual,
+                       void *user_data,
+                       bson_error_t *error)
+{
+   bool ret = false;
+   BSON_UNUSED (user_data);
+
+   bson_iter_t iter;
+   bson_iter_init (&iter, assertion);
+   BSON_ASSERT (bson_iter_next (&iter));
+   if (!BSON_ITER_HOLDS_DOCUMENT (&iter)) {
+      MATCH_ERR ("%s", "$$matchAsRoot does not contain a document");
+      goto done;
+   }
+
+   if (!actual) {
+      MATCH_ERR ("%s", "does not exist but should");
+      goto done;
+   }
+
+   if (bson_val_type (actual) != BSON_TYPE_DOCUMENT) {
+      MATCH_ERR ("%s", "value is not a document");
+      goto done;
+   }
+
+   bson_matcher_context_t as_root_context = *context;
+   as_root_context.is_root = true;
+
+   bson_val_t *expected_val = bson_val_from_iter (&iter);
+   ret = bson_matcher_match (&as_root_context, expected_val, actual, error);
+   bson_val_destroy (expected_val);
+
 done:
    return ret;
 }
 
 static bool
-evaluate_special (
-   bson_matcher_t *matcher, const bson_t *assertion, const bson_val_t *actual, const char *path, bson_error_t *error)
+evaluate_special (const bson_matcher_context_t *context,
+                  const bson_t *assertion,
+                  const bson_val_t *actual,
+                  bson_error_t *error)
 {
    bson_iter_t iter;
    const char *assertion_key;
@@ -305,10 +387,10 @@ evaluate_special (
    BSON_ASSERT (bson_iter_next (&iter));
    assertion_key = bson_iter_key (&iter);
 
-   LL_FOREACH (matcher->specials, special_iter)
+   LL_FOREACH (context->matcher->specials, special_iter)
    {
       if (0 == strcmp (assertion_key, special_iter->keyword)) {
-         return special_iter->fn (matcher, assertion, actual, special_iter->ctx, path, error);
+         return special_iter->fn (context, assertion, actual, special_iter->user_data, error);
       }
    }
 
@@ -327,12 +409,14 @@ bson_matcher_new (void)
    bson_matcher_add_special (matcher, "$$type", special_type, NULL);
    bson_matcher_add_special (matcher, "$$unsetOrMatches", special_unset_or_matches, NULL);
    bson_matcher_add_special (matcher, "$$matchesHexBytes", special_matches_hex_bytes, NULL);
+   bson_matcher_add_special (matcher, "$$matchAsDocument", special_match_as_document, NULL);
+   bson_matcher_add_special (matcher, "$$matchAsRoot", special_match_as_root, NULL);
    return matcher;
 }
 
 /* Add a hook function for matching a special $$ operator */
 void
-bson_matcher_add_special (bson_matcher_t *matcher, const char *keyword, special_fn special, void *ctx)
+bson_matcher_add_special (bson_matcher_t *matcher, const char *keyword, special_fn special, void *user_data)
 {
    special_functor_t *functor;
 
@@ -343,7 +427,7 @@ bson_matcher_add_special (bson_matcher_t *matcher, const char *keyword, special_
    functor = bson_malloc (sizeof (special_functor_t));
    functor->keyword = bson_strdup (keyword);
    functor->fn = special;
-   functor->ctx = ctx;
+   functor->user_data = user_data;
    LL_PREPEND (matcher->specials, functor);
 }
 
@@ -365,15 +449,12 @@ bson_matcher_destroy (bson_matcher_t *matcher)
 }
 
 bool
-bson_matcher_match (bson_matcher_t *matcher,
+bson_matcher_match (const bson_matcher_context_t *context,
                     const bson_val_t *expected,
                     const bson_val_t *actual,
-                    const char *path,
-                    bool array_of_root_docs,
                     bson_error_t *error)
 {
    bool ret = false;
-   bool is_root = (0 == strcmp (path, ""));
 
    if (bson_val_type (expected) == BSON_TYPE_DOCUMENT) {
       bson_iter_t expected_iter;
@@ -384,7 +465,7 @@ bson_matcher_match (bson_matcher_t *matcher,
 
       /* handle special operators (e.g. $$type) */
       if (is_special_match (expected_bson)) {
-         ret = evaluate_special (matcher, expected_bson, actual, path, error);
+         ret = evaluate_special (context, expected_bson, actual, error);
          goto done;
       }
 
@@ -401,7 +482,6 @@ bson_matcher_match (bson_matcher_t *matcher,
          bson_val_t *expected_val = NULL;
          bson_val_t *actual_val = NULL;
          bson_iter_t actual_iter;
-         char *path_child = NULL;
 
          key = bson_iter_key (&expected_iter);
          expected_val = bson_val_from_iter (&expected_iter);
@@ -412,9 +492,10 @@ bson_matcher_match (bson_matcher_t *matcher,
 
          if (bson_val_type (expected_val) == BSON_TYPE_DOCUMENT &&
              is_special_match (bson_val_to_document (expected_val))) {
-            bool special_ret;
-            path_child = bson_strdup_printf ("%s.%s", path, key);
-            special_ret = evaluate_special (matcher, bson_val_to_document (expected_val), actual_val, path, error);
+            char *path_child = bson_strdup_printf ("%s.%s", context->path, key);
+            bson_matcher_context_t special_context = {.matcher = context->matcher, .path = path_child};
+            bool special_ret =
+               evaluate_special (&special_context, bson_val_to_document (expected_val), actual_val, error);
             bson_free (path_child);
             bson_val_destroy (expected_val);
             bson_val_destroy (actual_val);
@@ -431,16 +512,18 @@ bson_matcher_match (bson_matcher_t *matcher,
             goto done;
          }
 
-         path_child = bson_strdup_printf ("%s.%s", path, key);
-         if (!bson_matcher_match (matcher, expected_val, actual_val, path_child, false, error)) {
-            bson_val_destroy (expected_val);
-            bson_val_destroy (actual_val);
-            bson_free (path_child);
-            goto done;
-         }
+         char *path_child = bson_strdup_printf ("%s.%s", context->path, key);
+         bson_matcher_context_t document_child_context = {
+            .matcher = context->matcher,
+            .path = path_child,
+         };
+         bool document_child_ret = bson_matcher_match (&document_child_context, expected_val, actual_val, error);
          bson_val_destroy (expected_val);
          bson_val_destroy (actual_val);
          bson_free (path_child);
+         if (!document_child_ret) {
+            goto done;
+         }
       }
 
       expected_keys = bson_count_keys (expected_bson);
@@ -451,8 +534,9 @@ bson_matcher_match (bson_matcher_t *matcher,
        * not present in the expected document.""
        *
        * This logic must also handle the case where `expected` is one of any
-       * number of root documents within an array (i.e. cursor result). */
-      if (!(is_root || array_of_root_docs) && expected_keys < actual_keys) {
+       * number of root documents within an array (i.e. cursor result); see
+       * array_child_context below. */
+      if (!context->is_root && expected_keys < actual_keys) {
          MATCH_ERR ("expected %" PRIu32 " keys in document, got: %" PRIu32, expected_keys, actual_keys);
          goto done;
       }
@@ -465,7 +549,6 @@ bson_matcher_match (bson_matcher_t *matcher,
       bson_iter_t expected_iter;
       const bson_t *expected_bson = bson_val_to_array (expected);
       const bson_t *actual_bson = NULL;
-      char *path_child = NULL;
       uint32_t expected_keys = bson_count_keys (expected_bson);
       uint32_t actual_keys;
 
@@ -499,17 +582,19 @@ bson_matcher_match (bson_matcher_t *matcher,
 
          actual_val = bson_val_from_iter (&actual_iter);
 
-         path_child = bson_strdup_printf ("%s.%s", path, key);
-         if (!bson_matcher_match (
-                matcher, expected_val, actual_val, path_child, (is_root && array_of_root_docs), error)) {
-            bson_val_destroy (expected_val);
-            bson_val_destroy (actual_val);
-            bson_free (path_child);
-            goto done;
-         }
+         char *path_child = bson_strdup_printf ("%s.%s", context->path, key);
+         bson_matcher_context_t array_child_context = {
+            .matcher = context->matcher,
+            .path = path_child,
+            .is_root = context->is_root && context->array_of_root_docs,
+         };
+         bool array_child_ret = bson_matcher_match (&array_child_context, expected_val, actual_val, error);
          bson_val_destroy (expected_val);
          bson_val_destroy (actual_val);
          bson_free (path_child);
+         if (!array_child_ret) {
+            goto done;
+         }
       }
       ret = true;
       goto done;
@@ -522,7 +607,7 @@ bson_matcher_match (bson_matcher_t *matcher,
 
    ret = true;
 done:
-   if (!ret && is_root) {
+   if (!ret && context->is_root) {
       /* Append the error with more context at the root match. */
       bson_error_t tmp_error;
 
@@ -541,9 +626,14 @@ done:
 bool
 bson_match (const bson_val_t *expected, const bson_val_t *actual, bool array_of_root_docs, bson_error_t *error)
 {
-   bson_matcher_t *matcher = bson_matcher_new ();
-   bool matched = bson_matcher_match (matcher, expected, actual, "", array_of_root_docs, error);
-   bson_matcher_destroy (matcher);
+   bson_matcher_context_t root_context = {
+      .matcher = bson_matcher_new (),
+      .path = "",
+      .is_root = true,
+      .array_of_root_docs = array_of_root_docs,
+   };
+   bool matched = bson_matcher_match (&root_context, expected, actual, error);
+   bson_matcher_destroy (root_context.matcher);
    return matched;
 }
 
@@ -557,22 +647,45 @@ typedef struct {
 static void
 test_match (void)
 {
-   testcase_t tests[] = {{"int32 ==", "{'a': 1}", "{'a': 1}", true},
-                         {"int32 !=", "{'a': 1}", "{'a': 0}", false},
-                         {"$$exists", "{'a': {'$$exists': true}}", "{'a': 0}", true},
-                         {"$$exists fail", "{'a': {'$$exists': true}}", "{'b': 0}", false},
-                         {"does not $$exists", "{'a': {'$$exists': false}}", "{'b': 0}", true},
-                         {"$$unsetOrMatches match", "{'a': {'$$unsetOrMatches': 1}}", "{'a': 1}", true},
-                         {"$$unsetOrMatches unset", "{'a': {'$$unsetOrMatches': 1}}", "{}", true},
-                         {"$$unsetOrMatches mismatch", "{'a': {'$$unsetOrMatches': 'abc'}}", "{'a': 1}", false},
-                         {"$$type match", "{'a': {'$$type': 'string'}}", "{'a': 'abc'}", true},
-                         {"$$type mismatch", "{'a': {'$$type': 'string'}}", "{'a': 1}", false},
-                         {"$$type array match", "{'a': {'$$type': ['string', 'int']}}", "{'a': 1}", true},
-                         {"$$type array mismatch", "{'a': {'$$type': ['string', 'int']}}", "{'a': 1.2}", false},
-                         {"extra keys in root ok", "{'a': 1}", "{'a': 1, 'b': 2}", true},
-                         {"extra keys in subdoc not ok", "{'a': {'b': 1}}", "{'a': {'b': 1, 'c': 2}}", false},
-                         {"numeric type mismatch is ok", "{'a': 1}", "{'a': 1.0}", true},
-                         {"comparing number to string is an error", "{'a': 1}", "{'a': 'foo'}", false}};
+   testcase_t tests[] = {
+      {"int32 ==", "{'a': 1}", "{'a': 1}", true},
+      {"int32 !=", "{'a': 1}", "{'a': 0}", false},
+      {"$$exists", "{'a': {'$$exists': true}}", "{'a': 0}", true},
+      {"$$exists fail", "{'a': {'$$exists': true}}", "{'b': 0}", false},
+      {"does not $$exists", "{'a': {'$$exists': false}}", "{'b': 0}", true},
+      {"$$unsetOrMatches match", "{'a': {'$$unsetOrMatches': 1}}", "{'a': 1}", true},
+      {"$$unsetOrMatches unset", "{'a': {'$$unsetOrMatches': 1}}", "{}", true},
+      {"$$unsetOrMatches mismatch", "{'a': {'$$unsetOrMatches': 'abc'}}", "{'a': 1}", false},
+      {"$$type match", "{'a': {'$$type': 'string'}}", "{'a': 'abc'}", true},
+      {"$$type mismatch", "{'a': {'$$type': 'string'}}", "{'a': 1}", false},
+      {"$$type array match", "{'a': {'$$type': ['string', 'int']}}", "{'a': 1}", true},
+      {"$$type array mismatch", "{'a': {'$$type': ['string', 'int']}}", "{'a': 1.2}", false},
+      {"extra keys in root ok", "{'a': 1}", "{'a': 1, 'b': 2}", true},
+      {"extra keys in subdoc not ok", "{'a': {'b': 1}}", "{'a': {'b': 1, 'c': 2}}", false},
+      {"extra keys in subdoc allowed explicitly",
+       "{'a': {'$$matchAsRoot': {'b': 1}}}",
+       "{'a': {'b': 1, 'c': 2}}",
+       true},
+      {"missing key in matchAsRoot subdoc",
+       "{'a': {'$$matchAsRoot': {'b': 1, 'd': 1}}}",
+       "{'a': {'b': 1, 'c': 2}}",
+       false},
+      {"$$matchAsDocument match", "{'a': {'$$matchAsDocument': {'b': 'abc'}}}", "{'a': '{\\'b\\':\\'abc\\'}'}", true},
+      {"$$matchAsDocument mismatch",
+       "{'a': {'$$matchAsDocument': {'b': 'abc'}}}",
+       "{'a': '{\\'b\\':\\'xyz\\'}'}",
+       false},
+      {"$$matchAsDocument parse error", "{'a': {'$$matchAsDocument': {'b': 'abc'}}}", "{'a': 'nope'}", false},
+      {"$$matchAsDocument extra keys not ok",
+       "{'a': {'$$matchAsDocument': {'b': 'abc'}}}",
+       "{'a': '{\\'b\\':\\'abc\\',\\'c\\':1}'}",
+       false},
+      {"$$matchAsDocument and $$matchAsRoot, extra keys ok",
+       "{'a': {'$$matchAsDocument': {'$$matchAsRoot': {'b': 'abc'}}}}",
+       "{'a': '{\\'b\\':\\'abc\\',\\'c\\':1}'}",
+       true},
+      {"numeric type mismatch is ok", "{'a': 1}", "{'a': 1.0}", true},
+      {"comparing number to string is an error", "{'a': 1}", "{'a': 'foo'}", false}};
    int i;
 
    for (i = 0; i < sizeof (tests) / sizeof (testcase_t); i++) {
