@@ -1,5 +1,5 @@
 /*
- * Copyright 2015 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,8 +14,8 @@
  * limitations under the License.
  */
 
-#include "mongoc/mongoc-array-private.h"
-#include "mongoc/mongoc-thread-private.h"
+#include <mongoc/mongoc-array-private.h>
+#include <mongoc/mongoc-thread-private.h>
 
 #include "sync-queue.h"
 
