@@ -40,10 +40,12 @@ _test_http_req (void)
    // Test generating an HTTP request for the IMDS server
    mcd_azure_imds_request req;
    mcd_azure_imds_request_init (&req, "example.com", 9879, "");
-   mcommon_string_t *req_str = _mongoc_http_render_request_head (&req.req);
+   mcommon_string_append_t req_str;
+   mcommon_string_new_as_append (&req_str);
+   _mongoc_http_render_request_head (&req_str, &req.req);
    mcd_azure_imds_request_destroy (&req);
    // Assert that we composed exactly the request that we expected
-   ASSERT_CMPSTR (req_str->str,
+   ASSERT_CMPSTR (mcommon_str_from_append (&req_str),
                   "GET "
                   "/metadata/identity/oauth2/"
                   "token?api-version=2018-02-01&resource=https%3A%2F%2Fvault."
@@ -53,7 +55,7 @@ _test_http_req (void)
                   "Metadata: true\r\n"
                   "Accept: application/json\r\n"
                   "\r\n");
-   mcommon_string_free (req_str, true);
+   mcommon_string_from_append_destroy (&req_str);
 }
 
 static const char *
