@@ -1,5 +1,5 @@
 #include <mongoc/mongoc.h>
-#include "mongoc/mongoc-client-private.h"
+#include <mongoc/mongoc-client-private.h>
 
 #include "TestSuite.h"
 #include "mock_server/mock-server.h"
