@@ -366,8 +366,8 @@ prose_test_4 (void *ctx)
    }
 
    mongoc_bulkwritereturn_t ret = mongoc_bulkwrite_execute (bw, NULL /* options */);
-   ASSERT_NO_BULKWRITEEXCEPTION (ret);
    ASSERT (ret.res);
+   ASSERT_NO_BULKWRITEEXCEPTION (ret);
    ASSERT_CMPINT64 (mongoc_bulkwriteresult_insertedcount (ret.res), ==, numModels);
    mongoc_bulkwriteexception_destroy (ret.exc);
    mongoc_bulkwriteresult_destroy (ret.res);
@@ -465,6 +465,7 @@ prose_test_5 (void *ctx)
    }
 
    mongoc_bulkwritereturn_t ret = mongoc_bulkwrite_execute (bw, NULL /* options */);
+   ASSERT (ret.res); // Has partial results.
    ASSERT (ret.exc);
 
    // Expect no top-level error.
@@ -535,6 +536,7 @@ prose_test_6 (void *ctx)
       mongoc_bulkwriteopts_t *opts = mongoc_bulkwriteopts_new ();
       mongoc_bulkwriteopts_set_ordered (opts, false);
       mongoc_bulkwritereturn_t ret = mongoc_bulkwrite_execute (bw, opts);
+      ASSERT (!ret.res); // No result due to no successful writes.
       ASSERT (ret.exc);
 
       if (mongoc_bulkwriteexception_error (ret.exc, &error)) {
@@ -574,6 +576,7 @@ prose_test_6 (void *ctx)
       mongoc_bulkwriteopts_t *opts = mongoc_bulkwriteopts_new ();
       mongoc_bulkwriteopts_set_ordered (opts, true);
       mongoc_bulkwritereturn_t ret = mongoc_bulkwrite_execute (bw, opts);
+      ASSERT (!ret.res); // No result due to no successful writes.
       ASSERT (ret.exc);
 
       if (mongoc_bulkwriteexception_error (ret.exc, &error)) {
@@ -655,7 +658,7 @@ prose_test_7 (void *ctx)
    mongoc_bulkwriteopts_t *opts = mongoc_bulkwriteopts_new ();
    mongoc_bulkwriteopts_set_verboseresults (opts, true);
    mongoc_bulkwritereturn_t ret = mongoc_bulkwrite_execute (bw, opts);
-
+   ASSERT (ret.res);
    ASSERT_NO_BULKWRITEEXCEPTION (ret);
 
    ASSERT_CMPINT64 (mongoc_bulkwriteresult_upsertedcount (ret.res), ==, 2);
@@ -741,7 +744,7 @@ prose_test_8 (void *ctx)
    mongoc_bulkwriteopts_t *opts = mongoc_bulkwriteopts_new ();
    mongoc_bulkwriteopts_set_verboseresults (opts, true);
    mongoc_bulkwritereturn_t ret = mongoc_bulkwrite_execute (bw, opts);
-
+   ASSERT (ret.res);
    ASSERT_NO_BULKWRITEEXCEPTION (ret);
 
    ASSERT_CMPINT64 (mongoc_bulkwriteresult_upsertedcount (ret.res), ==, 2);
@@ -842,13 +845,13 @@ prose_test_9 (void *ctx)
    mongoc_bulkwriteopts_t *opts = mongoc_bulkwriteopts_new ();
    mongoc_bulkwriteopts_set_verboseresults (opts, true);
    mongoc_bulkwritereturn_t ret = mongoc_bulkwrite_execute (bw, opts);
+   ASSERT (ret.res);
    ASSERT (ret.exc);
 
    if (!mongoc_bulkwriteexception_error (ret.exc, &error)) {
       test_error ("Expected top-level error but got:\n%s", test_bulkwriteexception_str (ret.exc));
    }
    ASSERT_ERROR_CONTAINS (error, MONGOC_ERROR_QUERY, 8, "Failing command via 'failCommand' failpoint");
-   ASSERT (ret.res);
    ASSERT_CMPSIZE_T ((size_t) mongoc_bulkwriteresult_upsertedcount (ret.res), ==, numModels);
 
    // Check length of update results.
@@ -911,12 +914,12 @@ prose_test_10 (void *ctx)
       ASSERT_OR_PRINT (ok, error);
 
       mongoc_bulkwritereturn_t ret = mongoc_bulkwrite_execute (bw, opts);
+      ASSERT (!ret.res); // No result due to unacknowledged write concern.
       ASSERT (ret.exc);
       if (!mongoc_bulkwriteexception_error (ret.exc, &error)) {
          test_error ("Expected top-level error but got:\n%s", test_bulkwriteexception_str (ret.exc));
       }
       ASSERT_ERROR_CONTAINS (error, MONGOC_ERROR_COMMAND, MONGOC_ERROR_COMMAND_INVALID_ARG, "of size");
-
       mongoc_bulkwriteexception_destroy (ret.exc);
       mongoc_bulkwriteresult_destroy (ret.res);
       mongoc_bulkwrite_destroy (bw);
@@ -929,12 +932,12 @@ prose_test_10 (void *ctx)
       ASSERT_OR_PRINT (ok, error);
 
       mongoc_bulkwritereturn_t ret = mongoc_bulkwrite_execute (bw, opts);
+      ASSERT (!ret.res); // No result due to unacknowledged write concern.
       ASSERT (ret.exc);
       if (!mongoc_bulkwriteexception_error (ret.exc, &error)) {
          test_error ("Expected top-level error but got:\n%s", test_bulkwriteexception_str (ret.exc));
       }
       ASSERT_ERROR_CONTAINS (error, MONGOC_ERROR_COMMAND, MONGOC_ERROR_COMMAND_INVALID_ARG, "of size");
-
       mongoc_bulkwriteexception_destroy (ret.exc);
       mongoc_bulkwriteresult_destroy (ret.res);
       mongoc_bulkwrite_destroy (bw);
@@ -1075,6 +1078,7 @@ prose_test_11 (void *ctx)
       // Execute.
       {
          mongoc_bulkwritereturn_t bwr = mongoc_bulkwrite_execute (tf->bw, NULL /* opts */);
+         ASSERT (bwr.res);
          ASSERT_NO_BULKWRITEEXCEPTION (bwr);
          ASSERT (mcommon_in_range_int64_t_unsigned (tf->numModels));
          ASSERT_CMPINT64 (mongoc_bulkwriteresult_insertedcount (bwr.res), ==, (int64_t) tf->numModels + 1);
@@ -1125,6 +1129,7 @@ prose_test_11 (void *ctx)
       // Execute.
       {
          mongoc_bulkwritereturn_t bwr = mongoc_bulkwrite_execute (tf->bw, NULL /* opts */);
+         ASSERT (bwr.res);
          ASSERT_NO_BULKWRITEEXCEPTION (bwr);
          ASSERT (mcommon_in_range_int64_t_unsigned (tf->numModels));
          ASSERT_CMPINT64 (mongoc_bulkwriteresult_insertedcount (bwr.res), ==, (int64_t) tf->numModels + 1);
@@ -1205,6 +1210,7 @@ prose_test_12 (void *ctx)
       // Execute.
       {
          mongoc_bulkwritereturn_t bwr = mongoc_bulkwrite_execute (bw, NULL);
+         ASSERT (!bwr.res); // No result due to no successful writes.
          ASSERT (bwr.exc);
          if (!mongoc_bulkwriteexception_error (bwr.exc, &error)) {
             test_error ("Expected top-level error but got:\n%s", test_bulkwriteexception_str (bwr.exc));
@@ -1233,6 +1239,7 @@ prose_test_12 (void *ctx)
       // Execute.
       {
          mongoc_bulkwritereturn_t bwr = mongoc_bulkwrite_execute (bw, NULL);
+         ASSERT (!bwr.res); // No result due to no successful writes.
          ASSERT (bwr.exc);
          if (!mongoc_bulkwriteexception_error (bwr.exc, &error)) {
             test_error ("Expected top-level error but got:\n%s", test_bulkwriteexception_str (bwr.exc));
@@ -1282,6 +1289,7 @@ prose_test_13 (void *ctx)
       // Execute.
       {
          mongoc_bulkwritereturn_t bwr = mongoc_bulkwrite_execute (bw, NULL);
+         ASSERT (!bwr.res); // No result due to no successful writes.
          ASSERT (bwr.exc);
          if (!mongoc_bulkwriteexception_error (bwr.exc, &error)) {
             test_error ("Expected top-level error but got:\n%s", test_bulkwriteexception_str (bwr.exc));
