@@ -20,6 +20,7 @@
 
 #include "TestSuite.h"
 #include "test-libmongoc.h"
+#include "test-conveniences.h"
 
 
 static void
@@ -73,7 +74,7 @@ test_sasl_canonicalize_hostname (void *ctx)
    BSON_UNUSED (ctx);
 
    client = test_framework_new_default_client ();
-   ss = mongoc_cluster_stream_for_reads (&client->cluster, NULL, NULL, NULL, NULL, &error);
+   ss = mongoc_cluster_stream_for_reads (&client->cluster, TEST_SS_LOG_CONTEXT, NULL, NULL, NULL, NULL, &error);
    ASSERT_OR_PRINT (ss, error);
 
    BSON_ASSERT (_mongoc_sasl_get_canonicalized_name (ss->stream, real_name, sizeof real_name));
