@@ -1,8 +1,8 @@
 #include "mock_server/mock-server.h"
 #include "mock_server/future.h"
 #include "mock_server/future-functions.h"
-#include "mongoc/mongoc.h"
-#include "mongoc/mongoc-gridfs-bucket-private.h"
+#include <mongoc/mongoc.h>
+#include <mongoc/mongoc-gridfs-bucket-private.h>
 #include "json-test.h"
 #include "TestSuite.h"
 #include "test-conveniences.h"
