@@ -16,8 +16,8 @@
 
 #include <mongoc/mongoc.h>
 
-#include "mongoc/mongoc-log-private.h"
-#include "mongoc/mongoc-trace-private.h"
+#include <mongoc/mongoc-log-private.h>
+#include <mongoc/mongoc-trace-private.h>
 #include "TestSuite.h"
 
 
