@@ -15,8 +15,8 @@
  */
 
 #include <mongoc/mongoc.h>
-#include "mongoc/mongoc-uri-private.h"
-#include "mongoc/mongoc-host-list-private.h"
+#include <mongoc/mongoc-uri-private.h>
+#include <mongoc/mongoc-host-list-private.h>
 
 #include "TestSuite.h"
 #include "test-libmongoc.h"
