@@ -3,8 +3,8 @@
 #include <mock_server/future.h>
 #include <mock_server/future-functions.h>
 
-#include "mongoc/mongoc-crypto-private.h"
-#include "mongoc/mongoc-scram-private.h"
+#include <mongoc/mongoc-crypto-private.h>
+#include <mongoc/mongoc-scram-private.h>
 
 #include "TestSuite.h"
 #include "test-conveniences.h"
