@@ -1,5 +1,5 @@
 /*
- * Copyright 2020-present MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -19,9 +19,9 @@
 #include <sys/utsname.h>
 #endif
 
-#include "mongoc/mongoc-client-private.h"
-#include "mongoc/mongoc-handshake.h"
-#include "mongoc/mongoc-handshake-private.h"
+#include <mongoc/mongoc-client-private.h>
+#include <mongoc/mongoc-handshake.h>
+#include <mongoc/mongoc-handshake-private.h>
 
 #include "TestSuite.h"
 #include "test-libmongoc.h"
