@@ -1,9 +1,9 @@
 #include <mongoc/mongoc.h>
 
-#include "mongoc/mongoc-client-private.h"
-#include "mongoc/mongoc-client-pool-private.h"
-#include "mongoc/mongoc-util-private.h"
-#include "mongoc/utlist.h"
+#include <mongoc/mongoc-client-private.h>
+#include <mongoc/mongoc-client-pool-private.h>
+#include <mongoc/mongoc-util-private.h>
+#include <mongoc/utlist.h>
 
 #include "mock_server/future.h"
 #include "mock_server/future-functions.h"
@@ -11,6 +11,7 @@
 #include "TestSuite.h"
 #include "test-conveniences.h"
 #include "test-libmongoc.h"
+#include <common-atomic-private.h>
 
 #undef MONGOC_LOG_DOMAIN
 #define MONGOC_LOG_DOMAIN "topology-reconcile-test"
@@ -68,7 +69,7 @@ selects_server (mongoc_client_t *client, mongoc_read_prefs_t *read_prefs, mock_s
 
    ASSERT (client);
 
-   sd = mongoc_topology_select (client->topology, MONGOC_SS_READ, read_prefs, NULL, &error);
+   sd = mongoc_topology_select (client->topology, MONGOC_SS_READ, TEST_SS_LOG_CONTEXT, read_prefs, NULL, &error);
 
    if (!sd) {
       fprintf (stderr, "%s\n", error.message);
@@ -233,7 +234,8 @@ _test_topology_reconcile_sharded (bool pooled)
    }
 
    primary_read_prefs = mongoc_read_prefs_new (MONGOC_READ_PRIMARY);
-   future = future_topology_select (client->topology, MONGOC_SS_READ, primary_read_prefs, NULL, &error);
+   future =
+      future_topology_select (client->topology, MONGOC_SS_READ, TEST_SS_LOG_CONTEXT, primary_read_prefs, NULL, &error);
 
    /* mongos */
    request = mock_server_receives_any_hello (mongos);
@@ -401,7 +403,7 @@ test_topology_reconcile_from_handshake (void *ctx)
    ASSERT_CMPINT (count, ==, 0);
 
    /* allow pool to start scanner thread */
-   bson_atomic_int_exchange (&topology->scanner_state, MONGOC_TOPOLOGY_SCANNER_OFF, bson_memory_order_seq_cst);
+   mcommon_atomic_int_exchange (&topology->scanner_state, MONGOC_TOPOLOGY_SCANNER_OFF, mcommon_memory_order_seq_cst);
    mongoc_client_pool_push (pool, client);
    client = mongoc_client_pool_pop (pool);
 
