@@ -17,30 +17,44 @@
 #ifndef UNIFIED_ENTITY_MAP_H
 #define UNIFIED_ENTITY_MAP_H
 
-#include "bson/bson.h"
-#include "mongoc/mongoc.h"
-#include "mongoc-array-private.h"
+#include <bson/bson.h>
+#include <mongoc/mongoc.h>
+#include <mongoc/mongoc-topology-description-private.h>
+#include <mongoc/mongoc-array-private.h>
+#include <common-thread-private.h>
 #include "bsonutil/bson-match.h"
 #include "test-diagnostics.h"
 
 typedef struct _event_t {
-   char *type;
-   char *command_name;
-   char *database_name;
-   bson_t *command;
-   bson_t *reply;
-   bson_oid_t service_id;
-   int64_t server_connection_id;
    struct _event_t *next;
+   const char *type;      // Non-owning
+   const char *eventType; // Non-owning
+   bson_t *serialized;
+   bool is_sensitive_command;
 } event_t;
 
+typedef bool (log_filter_func_t) (const mongoc_structured_log_entry_t *entry, void *user_data);
+
+typedef struct _log_message_t {
+   struct _log_message_t *next;
+   mongoc_structured_log_component_t component;
+   mongoc_structured_log_level_t level;
+   bson_t *message;
+} log_message_t;
+
+typedef struct _log_filter_t {
+   struct _log_filter_t *next;
+   log_filter_func_t *func;
+   void *user_data;
+} log_filter_t;
+
 typedef struct _observe_event_t {
-   const char *type; // Non-owning. Type of event to observe.
+   char *type; // Type of event to observe.
 } observe_event_t;
 
 typedef struct _store_event_t {
-   const char *entity_id; // Non-owning. Target entity to store event.
-   const char *type;      // Non-owning. Type of event to store.
+   char *entity_id; // Target entity to store event.
+   char *type;      // Type of event to store.
 } store_event_t;
 
 typedef struct _entity_t {
@@ -51,6 +65,9 @@ typedef struct _entity_t {
    bool *observe_sensitive_commands;
    struct _entity_t *next;
    event_t *events;
+   bson_mutex_t log_mutex;
+   log_message_t *log_messages;
+   log_filter_t *log_filters;
    struct _entity_map_t *entity_map; // Parent entity map.
    mongoc_array_t observe_events;    // observe_event_t [N].
    mongoc_array_t store_events;      // store_event_t [N].
@@ -93,6 +110,13 @@ bool
 entity_map_add_findcursor (
    entity_map_t *em, const char *id, mongoc_cursor_t *cursor, const bson_t *first_result, bson_error_t *error);
 
+/* Steals ownership of td. */
+bool
+entity_map_add_topology_description (entity_map_t *em,
+                                     const char *id,
+                                     mongoc_topology_description_t *td,
+                                     bson_error_t *error);
+
 /* Copies val */
 bool
 entity_map_add_bson (entity_map_t *em, const char *id, bson_val_t *val, bson_error_t *error);
@@ -108,10 +132,11 @@ entity_map_add_size_t (entity_map_t *em, const char *id, size_t *value, bson_err
 entity_t *
 entity_map_get (entity_map_t *em, const char *id, bson_error_t *error);
 
-/* Removes an entity from the entity map. Returns false and sets @error if @id
- * does not map to an entry. */
+/* Implements the 'close' operation. Doesn't fully remove the entity.
+ * Returns false and sets @error if @id does not map to an entry, or
+ * if the entity type does not support 'close' operations. */
 bool
-entity_map_delete (entity_map_t *em, const char *id, bson_error_t *error);
+entity_map_close (entity_map_t *em, const char *id, bson_error_t *error);
 
 mongoc_client_t *
 entity_map_get_client (entity_map_t *entity_map, const char *id, bson_error_t *error);
@@ -131,6 +156,9 @@ entity_map_get_changestream (entity_map_t *entity_map, const char *id, bson_erro
 entity_findcursor_t *
 entity_map_get_findcursor (entity_map_t *entity_map, const char *id, bson_error_t *error);
 
+mongoc_topology_description_t *
+entity_map_get_topology_description (entity_map_t *entity_map, const char *id, bson_error_t *error);
+
 void
 entity_findcursor_iterate_until_document_or_error (entity_findcursor_t *cursor,
                                                    const bson_t **document,
@@ -170,4 +198,18 @@ entity_map_set_reduced_heartbeat (entity_map_t *em, bool val);
 
 void
 entity_map_disable_event_listeners (entity_map_t *em);
+
+void
+entity_log_filter_push (entity_t *entity, log_filter_func_t *func, void *user_data);
+
+void
+entity_log_filter_pop (entity_t *entity, log_filter_func_t *func, void *user_data);
+
+void
+entity_map_log_filter_push (entity_map_t *entity_map, const char *entity_id, log_filter_func_t *func, void *user_data);
+
+void
+entity_map_log_filter_pop (entity_map_t *entity_map, const char *entity_id, log_filter_func_t *func, void *user_data);
+
+
 #endif /* UNIFIED_ENTITY_MAP_H */
